##  Step 6: Connect SAP LeanIX to Amazon Bedrock
  1. In the administration area of SAP LeanIX, navigate to Integrations.
  2. Choose Add Integrations.
  3. Under AI Agent Discovery, find the integration you need: AWS Bedrock Agents or AWS Bedrock AgentCore. Choose Configure.
  4. Enter a name for the integration.
  5. Enter the credentials copied from AWS into the corresponding fields.
  6. Save the changes.
